@@ -200,7 +200,8 @@ class TempestContextTestCase(test.TestCase):
 
         self.context.conf.set("compute", "flavor_ref", "")
         self.context._configure_option("compute", "flavor_ref",
-                                       helper_method=helper_method, flv_ram=64)
+                                       helper_method=helper_method, flv_ram=64,
+                                       flv_disk=5)
         self.assertEqual(1, helper_method.call_count)
 
         result = self.context.conf.get("compute", "flavor_ref")
@@ -234,9 +235,9 @@ class TempestContextTestCase(test.TestCase):
     def test__discover_or_create_flavor_when_flavor_exists(self):
         client = self.context.clients.nova()
         client.flavors.list.return_value = [fakes.FakeFlavor(id="id1", ram=64,
-                                                             vcpus=1, disk=0)]
+                                                             vcpus=1, disk=5)]
 
-        flavor = self.context._discover_or_create_flavor(64)
+        flavor = self.context._discover_or_create_flavor(64, 5)
         self.assertEqual("id1", flavor.id)
         self.assertEqual(0, len(self.context._created_flavors))
 
@@ -245,7 +246,7 @@ class TempestContextTestCase(test.TestCase):
         client.flavors.list.return_value = []
         client.flavors.create.side_effect = [fakes.FakeFlavor(id="id1")]
 
-        flavor = self.context._discover_or_create_flavor(64)
+        flavor = self.context._discover_or_create_flavor(64, 5)
         self.assertEqual("id1", flavor.id)
         self.assertEqual("id1", self.context._created_flavors[0].id)
 
@@ -269,6 +270,32 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual("subid1",
                          self.context._created_networks[0]["subnets"][0])
 
+    @mock.patch("rally_openstack.wrappers.network.NeutronWrapper.ext_gw_mode_enabled",  # noqa E501
+                new_callable=mock.PropertyMock, return_value=True)
+    def test__create_network_resources_public_network_override(self, mock_ext_gw_mode_enabled):  # noqa E501
+        client = self.context.clients.neutron()
+        conf = self.context.conf
+
+        conf.add_section("network")
+        conf.set("network", "public_network_id", "my-uuid")
+
+        fake_network = {
+            "id": "nid1",
+            "name": "network",
+            "status": "status"}
+
+        client.create_network.side_effect = [{"network": fake_network}]
+        client.create_router.side_effect = [{"router": {"id": "rid1"}}]
+        client.create_subnet.side_effect = [{"subnet": {"id": "subid1"}}]
+        client.list_networks.return_value = {"networks": []}
+
+        self.context._create_network_resources()
+        _name, pos, _kwargs = client.create_router.mock_calls[0]
+        router = pos[0]["router"]
+        external_gateway_info = router["external_gateway_info"]
+        self.assertEqual('my-uuid', external_gateway_info["network_id"])
+        self.assertEqual(True, external_gateway_info["enable_snat"])
+
     def test__cleanup_tempest_roles(self):
         self.context._created_roles = [fakes.FakeRole(), fakes.FakeRole()]
 
@@ -363,10 +390,12 @@ class TempestContextTestCase(test.TestCase):
                        helper_method=ctx._discover_or_create_image),
              mock.call("compute", "flavor_ref",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_ram,
+                       flv_disk=config.CONF.openstack.flavor_ref_disk),
              mock.call("compute", "flavor_ref_alt",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram)],
+                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram,
+                       flv_disk=config.CONF.openstack.flavor_ref_alt_disk)],
             mock__configure_option.call_args_list)
 
         mock_create_dir.reset_mock()
@@ -401,10 +430,12 @@ class TempestContextTestCase(test.TestCase):
                        helper_method=ctx._discover_or_create_image),
              mock.call("compute", "flavor_ref",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_ram,
+                       flv_disk=config.CONF.openstack.flavor_ref_disk),
              mock.call("compute", "flavor_ref_alt",
                        helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram),
+                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram,
+                       flv_disk=config.CONF.openstack.flavor_ref_alt_disk),
              mock.call("compute", "fixed_network_name",
                        helper_method=ctx._create_network_resources),
              mock.call("orchestration", "instance_type",
